@@ -3,16 +3,22 @@
 from unittest.case import TestCase
 
 from django.http.request import HttpRequest
-from mock.mock import patch
+from unittest.mock import patch
 
 from core_module_periodic_table_app.views import PeriodicTableModule
 
 
 class TestPeriodicTableModuleRetrieveData(TestCase):
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    """Test Periodic Table Module Retrieve Data"""
+
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_retrieve_data_returns_element_if_data_given(
         self, render_template
     ):
+        """test_periodic_table_module_retrieve_data_returns_element_if_data_given"""
+
         # Arrange
         request = HttpRequest()
         element = "AC"
@@ -25,10 +31,14 @@ class TestPeriodicTableModuleRetrieveData(TestCase):
         result = my_module._retrieve_data(request)
         self.assertEqual(True, result == element)
 
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_retrieve_data_returns_empty_if_no_data_given(
         self, render_template
     ):
+        """test_periodic_table_module_retrieve_data_returns_empty_if_no_data_given"""
+
         # Arrange
         request = HttpRequest()
         request.method = "GET"
@@ -38,10 +48,14 @@ class TestPeriodicTableModuleRetrieveData(TestCase):
         result = my_module._retrieve_data(request)
         self.assertEqual(True, result == "")
 
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_retrieve_data_returns_element_if_selected_data_given(
         self, render_template
     ):
+        """test_periodic_table_module_retrieve_data_returns_element_if_selected_data_given"""
+
         # Arrange
         request = HttpRequest()
         element = "AC"
@@ -54,10 +68,14 @@ class TestPeriodicTableModuleRetrieveData(TestCase):
         result = my_module._retrieve_data(request)
         self.assertEqual(True, result == element)
 
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_retrieve_data_returns_empty_if_no_selected_data_given(
         self, render_template
     ):
+        """test_periodic_table_module_retrieve_data_returns_empty_if_no_selected_data_given"""
+
         # Arrange
         request = HttpRequest()
         request.method = "POST"
@@ -69,10 +87,16 @@ class TestPeriodicTableModuleRetrieveData(TestCase):
 
 
 class TestPeriodicTableModuleRenderData(TestCase):
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    """Test Periodic Table Module Render Data"""
+
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_render_data_returns_the_chosen_element_if_given(
         self, render_template
     ):
+        """test_periodic_table_module_render_data_returns_the_chosen_element_if_given"""
+
         # Arrange
         request = HttpRequest()
         element = "AC"
@@ -82,10 +106,14 @@ class TestPeriodicTableModuleRenderData(TestCase):
         result = my_module._render_data(request)
         self.assertEqual(True, result == "Chosen element: " + element)
 
-    @patch("core_parser_app.tools.modules.views.module.AbstractModule.render_template")
+    @patch(
+        "core_parser_app.tools.modules.views.module.AbstractModule.render_template"
+    )
     def test_periodic_table_module_render_data_returns_no_selected_element_if_not_given(
         self, render_template
     ):
+        """test_periodic_table_module_render_data_returns_no_selected_element_if_not_given"""
+
         # Arrange
         request = HttpRequest()
         element = ""
